@@ -1,4 +1,5 @@
 import logging
+from configparser import ConfigParser
 from datetime import datetime
 from logging.handlers import RotatingFileHandler
 import os
@@ -15,9 +16,13 @@ rHandler.setLevel(logging.DEBUG)
 formatter = logging.Formatter("%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s")
 rHandler.setFormatter(formatter)
 console = logging.StreamHandler()
-console.setLevel(logging.INFO)
+console.setLevel(logging.DEBUG)
 
-logging.basicConfig(level=logging.INFO,
+configParser = ConfigParser()
+configParser.read('conf/config.ini')
+level = configParser.get('logging', 'level')
+
+logging.basicConfig(level=level,
                     format='%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s',
                     handlers=[rHandler, console])
 
